Django Suit documentation — Django Suit 0.1.4 documentation

### Navigation

- index
- next |
- Django Suit 0.1.4 documentation »

# Django Suit documentation

Modern theme for Django admin interface.

Django Suit is alternative theme/skin/extension for Django administration interface.

# About

- Home page: http://djangosuit.com
- Demo: http://djangosuit.com/admin/
- Licence and Pricing: http://djangosuit.com/pricing/
- Github: https://github.com/darklow/django-suit
- Demo app on Github: https://github.com/darklow/django-suit-examples
- Changelog: Changelog.rst
- Supports: Django 1.4/1.5c2

# Installation

1. You can get Django Suit by using pip or easy_install:

       pip install django-suit
       # or
       easy_install django-suit

2. You will need to add the `'suit'` application to the `INSTALLED_APPS` setting of your Django project `settings.py` file.:

       INSTALLED_APPS = (
           ...
           'suit',
           'django.contrib.admin',
       )

> Warning

> `'suit'` must be added before `'django.contrib.admin'`

3. You also need to add `'django.core.context_processors.request'` to `TEMPLATE_CONTEXT_PROCESSORS` setting in your Django project `settings.py` file.:

       from django.conf.global_settings import TEMPLATE_CONTEXT_PROCESSORS as TCP

       TEMPLATE_CONTEXT_PROCESSORS = TCP + (
           'django.core.context_processors.request',
       )

> Note: This is required to handle left side menu. If by some reason you removed original Django Suit `menu.html`, you can skip this.

## Deployment

Deployment with Django Suit should not be different than any other Django application. If you have problems with deployment on production, read Django docs on wsgi first.

Note

If you deploy your project with Apache or `Debug=False` don’t forget to run `./manage.py collectstatic`

# Configuration

You can customize Django Suit behaviour by adding `SUIT_CONFIG` configuration variable to your Django project `settings.py` file.

- Configuration
  - Full example
- Header
  - ADMIN_NAME
  - HEADER_DATE_FORMAT
  - HEADER_TIME_FORMAT
- Forms
  - SHOW_REQUIRED_ASTERISK
  - CONFIRM_UNSAVED_CHANGES
- Menu
  - SEARCH_URL
  - MENU_OPEN_FIRST_CHILD
  - MENU_ICONS
  - MENU_EXCLUDE
  - MENU_ORDER
- List
  - LIST_PER_PAGE

# Template customization

You must extend `base_site.html` template to customize footer links, copyright text or to add extra JS/CSS files. Example file is available on github.

Copy customized `base_site.html` template file to your project’s main application `template/admin/` directory and un-comment and edit the blocks you would like to extend.

Alternatively you can copy `base_site.html` to any of template directories, which are defined in `TEMPLATE_DIRS` setting (if any). By default Django looks in every registered application `templates/` dir.

In the same way you can override any of Django Suit admin templates. More about customizing project’s templates, you can read in Django Admin Tutorial

# Widgets

There are handy widgets included in Django Suit.

- Widgets
- NumberInput
- HTML5Input
- EnclosedInput
- AutosizedTextarea
- Date/Time widgets
- LinkedSelect
- JavaScript goodies

# Sortables

Sortables are handy admin tools for ordering different lists.

- Sortables
- Limitations
- Under the hood
- Change list sortable
  - Example
- django-mptt tree sortable
  - Example
- Tabular inlines sortable
  - Example

# Examples

Besides documentation examples, Django Suit demo application source code is also available on separate github repository: django-suit-examples. If you see anything in demo application, you can always go to this repository and see implementation and code in one of `models.py` or `admin.py` files

# Contributing

Separate django-suit-contrib package is available with full Django Suit development project setup, tests and instructions.

### Navigation

- index
- next |
- Django Suit 0.1.4 documentation »